import {Component} from '@angular/core';

import Swal from 'sweetalert2';

enum Result {
  Format = 'Format_invalid',
  Key = 'Key_invalid',
  Ok = 'Ok',
}

class N_INSEE {
  private static readonly _Format: RegExp = /^[12][0-9]{2}(0[1-9]|[1][0-2])([0-9]{2}|2A|2B)[0-9]{3}[0-9]{3}$/gm; // 'new RegExp('^(?!000)(\\d{13}$)');'
  constructor(private readonly _n_insee: number, private readonly _clef: number) {
    if (this._n_insee.toString().match(N_INSEE._Format)) {
      if (this._calcul_clef()) {
        this._result = Result.Ok;
      } else {
        this._result = Result.Key;
      }
    } else {
      this._result = Result.Format;
    }
  }

  private _result: Result;
  get result(): Result {
    return this._result;
  }

  get n_insee(): string {
    return this._n_insee.toString();
  }

  get clef(): string {
    return this._clef.toString();
  }

  private _calcul_clef(): boolean {
    if ((97 - (this._n_insee % 97)) === this._clef) {
      return true;
    } else {
      return false;
    }
  }
}

@Component({
  selector: 'app-insee',
  templateUrl: './insee.component.html',
  styleUrls: ['./insee.component.css']
})
export default class INSEE_component {
  public list_of_N_INSEE = new Array<N_INSEE>();

  new() {
    Swal.mixin({
      input: 'text',
      confirmButtonText: 'Next &rarr;',
      showCancelButton: true,
      progressSteps: ['1', '2']
    }).queue([
      {
        title: 'N°INSEE',
        text: '(saisir clef juste après)'
      },
      'Clef'
    ]).then((result) => {
      if (result.value) {
        window.console.assert(result.value instanceof Array, '\'result.value instanceof Array\', untrue?');
        window.console.assert(result.value.length === 2, '\'result.value.length === 2\', untrue?');
        this.list_of_N_INSEE.push(new N_INSEE(Number.parseInt(result.value[0]), Number.parseInt(result.value[1])));
        Swal.fire({
          title: 'Résultat',
          html: `${result.value[0]} (clef : ${result.value[1]}):&nbsp;<pre><code>${this.list_of_N_INSEE[this.list_of_N_INSEE.length - 1].result}</code></pre>`,
          confirmButtonText: 'Bye bye...'
        });
      }
    });
  }
}
